* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120 NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON; ODS LISTING;  

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
*******          BEGIN EXAMPLE 3 DATA IMPORT AND MANIPULATION            *******;  
********************************************************************************;

* Define global variable for file location to be replaced in code below;
* \\Client\ precedes path in Virtual Desktop outside H drive;
%LET filesave= C:\Dropbox\22SP_PSQF6243\PSQF6243_Example4a;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example4a";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example4a DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* All data transformations must be inside a DATA+SET combo to know where to use them;
* Here is how to make a new variable: new = old;
DATA work.Example4a; SET work.Example4a;
* Create and label predictor variables for model 1 (same as in Example 2);
  * Linear predictor for education centered so that 0 is meaningful;
    educ12=educ-12; 
    LABEL educ12= "educ12: Education (0=12 years)";
  * Recode binary marry predictor so that 0 is meaningful;
    marry01=.; * Create new empty variable, then recode;
    IF marry=1 THEN marry01=0;
    IF marry=2 THEN marry01=1;
    LABEL marry01= "marry01: 0=unmarried, 1=married";
* Create and label predictor variables for model 2 (same as in Example 3);
  * 2 Indicator-dummy-coded binary predictors for workclass;
    LvM=.; LvU=.; * Make new empty variables;
    IF workclass=1 THEN DO; LvM=0; LvU=0; END; * Replace each for lower;
    IF workclass=2 THEN DO; LvM=1; LvU=0; END; * Replace each for middle;
    IF workclass=3 THEN DO; LvM=0; LvU=1; END; * Replace each for upper; 
    LABEL LvM="LvM: Low=0 vs Mid=1 Class"
          LvU="LvU: Low=0 vs Upp=1 Class";
  * Center age at 18 (minimum in sample);
    age18=age-18; 
    LABEL age18= "age18: Age (0=18 years)";
  * 3 Piecewise slopes for education;
    lessHS=.; gradHS=.; overHS=.; * Make three new empty variables;
    * Replace for educ less than 12;
      IF educ LT 12 THEN DO; lessHS=educ-11; gradHS=0; overHS=0;       END;
    * Replace for educ greater or equal to 12;
      IF educ GE 12 THEN DO; lessHS=0;       gradHS=1; overHS=educ-12; END;
      LABEL lessHS= "lessHS: Slope for Years Ed Less Than High School"
            gradHS= "gradHS: Bump for Graduating High School"
            overHS= "overHS: Slope for Years Ed After High School";
* Label outcome;
  LABEL income= "income: Annual Income in 1000s";
* Select cases complete on variables;
  WHERE NMISS(income,educ,marry,workclass,age)=0;
RUN;
* Now dataset work.Example4a is ready to use; 

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example4a_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

********************************************************************************;
*******    MODEL 1: DEMONSTRATING SINGLE-SLOPE PREDICTORS COMBINED       *******;
********************************************************************************;

TITLE "SAS Predict Income from Empty Model";
PROC GLM DATA=work.Example4a NAMELEN=100;
  MODEL income = / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;
TITLE "SAS Predict Income from Linear Education Only";
PROC GLM DATA=work.Example4a NAMELEN=100;
  MODEL income = educ12 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;
TITLE "SAS Predict Income from Binary Marital Status Only";
PROC GLM DATA=work.Example4a NAMELEN=100;
  MODEL income = marry01 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Model 1: Predict Income from Linear Education and Binary Marital Status";
PROC GLM DATA=work.Example4a NAMELEN=100;
  MODEL income = educ12 marry01 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
* Save for computing slope-specific effect sizes;
  ODS OUTPUT ParameterEstimates=Model1Estimates; 
RUN; QUIT; TITLE;

* Demonstrating how to compute effect sizes: partial d, semi-partial and partial r;
DATA work.Model1Estimates; SET work.Model1Estimates; 
* Define placeholder for denominator DF and model R2;
  %LET df=731; %LET R2=0.190287;
* Cohen partial d not given anywhere in output;
  pD=(2*tvalue)/SQRT(&df.); 
* Partial R2 already given by SAS;
  pR=tvalue/SQRT((tvalue*tvalue)+&df.);
* Semi-partial R2 already given by SAS;
  sR=tvalue*SQRT((1-&R2.)/&df.);
RUN;

* Print effect sizes;
TITLE "SAS Model 1 Solution and Effect Sizes";
PROC PRINT NOOBS DATA=work.Model1Estimates; 
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;    
     VAR Parameter Estimate StdErr tvalue probt pD pr sr; 
RUN; TITLE;


********************************************************************************;
*******    MODEL 2: DEMONSTRATING MULTIPLE-SLOPE PREDICTORS COMBINED     *******;
********************************************************************************;

TITLE "SAS Predict Income from 3-Category Workclass Only";
PROC GLM DATA=work.Example4a NAMELEN=100;
     MODEL income = LvM LvU / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;
TITLE "SAS Predict Income from Linear+Quadratic Age Only";
PROC GLM DATA=work.Example4a NAMELEN=100;
     MODEL income = age18 age18*age18 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;
TITLE "SAS Predict Income from 3 Piecewise Slopes for Education Only";
PROC GLM DATA=work.Example4a NAMELEN=100;
     MODEL income = lessHS gradHS overHS / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Model 2: Predict Income from WorkClass, Quadratic Age, and Piecewise Education";
PROC GLM DATA=work.Example4a NAMELEN=100;
* Combined model with all 7 slopes;
  MODEL income = LvM LvU age18 age18*age18 lessHS gradHS overHS  
                 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
* Ask for missing model-implied group difference;
  ESTIMATE "Mid v Upp Diff"  LvM -1 LvU 1;

* Replicate F-test and R2 for the model: includes all 7 slopes;
  CONTRAST "F-test (DFnum=7) for model" 
            LvM 1, LvU 1, age18 1, age18*age18 1, lessHS 1, gradHS 1, overHS 1; 
* Ask for F-test and semi-partial R2 for overall effect of workclass;
  CONTRAST "F-test (DFnum=2) for overall workclass" LvM 1, LvU 1;
* Ask for F-test and semi-partial R2 for overall effect of age;
  CONTRAST "F-test (DFnum=2) for overall age" age18 1, age18*age18 1;
* Ask for F-test and semi-partial R2 for overall effect of education;
  CONTRAST "F-test (DFnum=3) for overall education" lessHS 1, gradHS 1, overHS 1;

* Save for computing slope-specific effect sizes;
  ODS OUTPUT ParameterEstimates=Model2Estimates Estimates=Req2Estimates; 
RUN; QUIT; TITLE;

* Demonstrating how to compute effect sizes: partial d, semi-partial and partial r;
DATA work.Model2Estimates; LENGTH Parameter $50; 
     SET Req2Estimates work.Model2Estimates; 
* Define placeholder for denominator DF and model R2;
  %LET df=726; %LET R2=0.288664;
* Cohen partial d not given anywhere in output;
  pD=(2*tvalue)/SQRT(&df.); 
* Partial R2 already given by SAS;
  pR=tvalue/SQRT((tvalue*tvalue)+&df.); 
* Semi-partial R2 already given by SAS;
  sR=tvalue*SQRT((1-&R2.)/&df.); 
RUN;

* Print effect sizes;
TITLE "SAS Model 2 Solution and Effect Sizes";
PROC PRINT NOOBS DATA=work.Model2Estimates; 
     WHERE INDEX(Parameter,"Intercept")=0; * Do not print intercept;    
     VAR Parameter Estimate StdErr tvalue probt pD pr sr; 
RUN; TITLE;


* Close output;
ODS RTF CLOSE;

